@@ -14,12 +14,6 @@ pub fn clone_fallback_name(fallback: &Option<String>) -> Option<String> {
     }
 }
 
-pub const DBL_EPSILON: f64 = 1e-10;
-
-pub fn double_equals(a: f64, b: f64) -> bool {
-    (a - b).abs() < DBL_EPSILON
-}
-
 /// Converts a `char *` which is known to be valid UTF-8 into a `&str`
 ///
 /// The usual `from_glib_none(s)` allocates an owned String.  The
